==> kdevelop-php-1.6.90.tar.xz: kdevelop-php-1.6.90/kdevphpsupport.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=Service
Exec=blubb
Comment=PHP Language Support
Comment[bs]=Podrška za PHP jezik
Comment[ca]=Implementació del llenguatge PHP
Comment[ca@valencia]=Implementació del llenguatge PHP
Comment[cs]=Podpora jazyka PHP
Comment[da]=Understøttelse af sproget PHP
Comment[de]=Sprachunterstützung für PHP
Comment[el]=Υποστήριξη γλώσσας PHP
Comment[es]=Implementación del lenguaje PHP
Comment[et]=PHP keele toetus
Comment[fi]=PHP-kielituki
Comment[fr]=Prise en charge du langage PHP
Comment[ga]=Tacaíocht PHP
Comment[gl]=Soporte da linguaxe PHP
Comment[hu]=PHP nyelvi támogatás
Comment[it]=Supporto al linguaggio PHP
Comment[kk]=PHP тілін қолдау
Comment[ko]=PHP 언어 지원
Comment[lt]=Php kalbos palaikymas
Comment[mr]=पीएचपी भाषा समर्थन
Comment[nb]=PHP språkstøtte
Comment[nds]=Ünnerstütten för PHP
Comment[nl]=Ondersteuning voor PHP-taal
Comment[pl]=Obsługa języka PHP
Comment[pt]=Suporte à Linguagem PHP
Comment[pt_BR]=Suporte à linguagem PHP
Comment[ru]=Поддержка языка PHP
Comment[sk]=Jazyková podpora PHP
Comment[sl]=Podpora jeziku PHP
Comment[sv]=Stöd för språket PHP
Comment[tr]=PHP Dili Desteği
Comment[ug]=PHP تىلىنى قوللاش
Comment[uk]=Підтримка мови PHP
Comment[x-test]=xxPHP Language Supportxx
Comment[zh_CN]=Php 语言支持
Comment[zh_TW]=PHP 語言支援
Name=PHP Language Support
Name[bs]=Podrška za PHP jezik
Name[ca]=Implementació del llenguatge PHP
Name[ca@valencia]=Implementació del llenguatge PHP
Name[cs]=Podpora jazyka PHP
Name[da]=Understøttelse af sproget PHP
Name[de]=Sprachunterstützung für PHP
Name[el]=Υποστήριξη γλώσσας PHP
Name[en_GB]=PHP Language Support
Name[es]=Implementación del lenguaje PHP
Name[et]=PHP keele toetus
Name[fi]=PHP-kielituki
Name[fr]=Prise en charge du langage PHP
Name[ga]=Tacaíocht PHP
Name[gl]=Soporte da linguaxe PHP
Name[hu]=PHP nyelvi támogatás
Name[it]=Supporto al linguaggio PHP
Name[kk]=PHP тілін қолдау
Name[ko]=PHP 언어 지원
Name[lt]=Php kalbos palaikymas
Name[mr]=पीएचपी भाषा समर्थन
Name[nb]=PHP språkstøtte
Name[nds]=Ünnerstütten för PHP
Name[nl]=Ondersteuning voor PHP-taal
Name[pl]=Obsługa języka PHP
Name[pt]=Suporte à Linguagem PHP
Name[pt_BR]=Suporte à linguagem PHP
Name[ru]=Поддержка языка PHP
Name[sk]=Jazyková podpora PHP
Name[sl]=Podpora jeziku PHP
Name[sv]=Stöd för språket PHP
Name[tr]=PHP Dili Desteği
Name[ug]=PHP تىلىنى قوللاش
Name[uk]=Підтримка мови PHP
Name[x-test]=xxPHP Language Supportxx
Name[zh_CN]=Php 语言支持
Name[zh_TW]=PHP 語言支援
ServiceTypes=KDevelop/Plugin
Icon=application-x-php
X-KDE-Library=kdevphplanguagesupport
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Language=Php
X-KDevelop-Args=PHP
X-KDevelop-Interfaces=ILanguageSupport
X-KDevelop-SupportedMimeTypes=application/x-php
X-KDE-PluginInfo-Name=KDevPhpSupport
X-KDE-PluginInfo-Category=Language Support
X-KDevelop-Mode=NoGUI
X-KDevelop-LoadMode=AlwaysOn

==> kdevelop-php-1.7.2.tar.xz: kdevelop-php-1.7.2/kdevphpsupport.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=Service
Exec=blubb
Comment=PHP Language Support
Comment[bs]=Podrška za PHP jezik
Comment[ca]=Implementació del llenguatge PHP
Comment[ca@valencia]=Implementació del llenguatge PHP
Comment[cs]=Podpora jazyka PHP
Comment[da]=Understøttelse af sproget PHP
Comment[de]=Sprachunterstützung für PHP
Comment[el]=Υποστήριξη γλώσσας PHP
Comment[en_GB]=PHP Language Support
Comment[es]=Implementación del lenguaje PHP
Comment[et]=PHP keele toetus
Comment[fi]=PHP-kielituki
Comment[fr]=Prise en charge du langage PHP
Comment[gl]=Soporte da linguaxe PHP
Comment[hu]=PHP nyelvi támogatás
Comment[it]=Supporto al linguaggio PHP
Comment[kk]=PHP тілін қолдау
Comment[ko]=PHP 언어 지원
Comment[mr]=पीएचपी भाषा समर्थन
Comment[nb]=PHP språkstøtte
Comment[nds]=Ünnerstütten för PHP
Comment[nl]=Ondersteuning voor PHP-taal
Comment[pl]=Obsługa języka PHP
Comment[pt]=Suporte à Linguagem PHP
Comment[pt_BR]=Suporte à linguagem PHP
Comment[ru]=Поддержка языка PHP
Comment[sk]=Jazyková podpora PHP
Comment[sl]=Podpora jeziku PHP
Comment[sv]=Stöd för språket PHP
Comment[tr]=PHP Dili Desteği
Comment[uk]=Підтримка мови PHP
Comment[x-test]=xxPHP Language Supportxx
Comment[zh_CN]=PHP 语言支持
Comment[zh_TW]=PHP 語言支援
Name=PHP Language Support
Name[bs]=Podrška za PHP jezik
Name[ca]=Implementació del llenguatge PHP
Name[ca@valencia]=Implementació del llenguatge PHP
Name[cs]=Podpora jazyka PHP
Name[da]=Understøttelse af sproget PHP
Name[de]=Sprachunterstützung für PHP
Name[el]=Υποστήριξη γλώσσας PHP
Name[en_GB]=PHP Language Support
Name[es]=Implementación del lenguaje PHP
Name[et]=PHP keele toetus
Name[fi]=PHP-kielituki
Name[fr]=Prise en charge du langage PHP
Name[ga]=Tacaíocht PHP
Name[gl]=Soporte da linguaxe PHP
Name[hu]=PHP nyelvi támogatás
Name[it]=Supporto al linguaggio PHP
Name[kk]=PHP тілін қолдау
Name[ko]=PHP 언어 지원
Name[mr]=पीएचपी भाषा समर्थन
Name[nb]=PHP språkstøtte
Name[nds]=Ünnerstütten för PHP
Name[nl]=Ondersteuning voor PHP-taal
Name[pl]=Obsługa języka PHP
Name[pt]=Suporte à Linguagem PHP
Name[pt_BR]=Suporte à linguagem PHP
Name[ru]=Поддержка языка PHP
Name[sk]=Jazyková podpora PHP
Name[sl]=Podpora jeziku PHP
Name[sv]=Stöd för språket PHP
Name[tr]=PHP Dili Desteği
Name[ug]=PHP تىلىنى قوللاش
Name[uk]=Підтримка мови PHP
Name[x-test]=xxPHP Language Supportxx
Name[zh_CN]=PHP 语言支持
Name[zh_TW]=PHP 語言支援
ServiceTypes=KDevelop/Plugin
Icon=application-x-php
X-KDE-Library=kdevphplanguagesupport
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Language=Php
X-KDevelop-Args=PHP
X-KDevelop-Interfaces=ILanguageSupport
X-KDevelop-SupportedMimeTypes=application/x-php
X-KDE-PluginInfo-Name=KDevPhpSupport
X-KDE-PluginInfo-Category=Language Support
X-KDevelop-Mode=NoGUI
X-KDevelop-LoadMode=AlwaysOn
